==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/mn-MN/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Энэ хэрэглэгч нэвтрэх эрхтэй',
    'activated_disabled_help_text' => 'Та өөрийн дансны идэвхжүүлэх статусыг засах боломжгүй.',
    'assets_user'       => 'Нэр:',
    'bulk_update_warn'	=> 'Та: user_count хэрэглэгчдийн шинж чанарыг засах гэж байна. Энэ маягтыг ашиглан өөрийн хэрэглэгчийн атрибутуудыг өөрчлөх боломжгүй гэдгийг анхаарна уу. Мөн өөрийн хэрэглэгчдэд тус бүрд засвар хийлгэх ёстой.',
    'bulk_update_help'	=> 'Энэ маягт нь олон хэрэглэгчийг нэгэн зэрэг шинэчлэх боломжийг олгоно. Зөвхөн өөрчлөх шаардлагатай талбаруудыг бөглөөрэй. Хоосон үлдсэн талбарууд өөрчлөгдөхгүй хэвээр үлдэнэ.',
    'current_assets'    => 'Одоогоор ашиглагдаж буй активууд энэ хэрэглэгчийг шалгасан байна',
    'clone'             => 'Clone Хэрэглэгч',
    'contact_user'      => 'Холбоо барих нэр',
    'edit'              => 'Хэрэглэгчийг засварлах',
    'filetype_info'     => 'Зөвшөөрөгдсөн filetypes нь png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Түүх: нэр',
    'info'				=> 'Мэдээлэл',
    'restore_user'		=> 'Тэднийг сэргээхийн тулд энд дарна уу.',
    'last_login'        => 'Сүүлчийн Нэвтрэх',
    'ldap_config_text'  => 'LDAP тохиргооны тохиргоог Админ> Тохиргоо гэж олж болно. (Заавал биш) сонгосон байршлыг бүх импортлогчдын хувьд тохируулах болно.',
    'print_assigned'    => 'Бүх хуваарилагдсан хөрөнгийг хэвлэх',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Програм хангамж: нэр',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Хэрэглэгч: нэрийг харах',
    'usercsv'           => 'CSV файл',
    'two_factor_admin_optin_help' => 'Таны одоогийн админ тохиргоо нь хоёр хүчин зүйлийн баталгаажуулалтыг сонгохыг зөвшөөрдөг.',
    'two_factor_enrolled' => '2FA төхөөрөмжийг бүртгүүлсэн',
    'two_factor_active'   => '2FA идэвхтэй',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/mn-MN/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Энэ хэрэглэгч нэвтрэх эрхтэй',
    'activated_disabled_help_text' => 'Та өөрийн дансны идэвхжүүлэх статусыг засах боломжгүй.',
    'assets_user'       => 'Нэр:',
    'bulk_update_warn'	=> 'Та: user_count хэрэглэгчдийн шинж чанарыг засах гэж байна. Энэ маягтыг ашиглан өөрийн хэрэглэгчийн атрибутуудыг өөрчлөх боломжгүй гэдгийг анхаарна уу. Мөн өөрийн хэрэглэгчдэд тус бүрд засвар хийлгэх ёстой.',
    'bulk_update_help'	=> 'Энэ маягт нь олон хэрэглэгчийг нэгэн зэрэг шинэчлэх боломжийг олгоно. Зөвхөн өөрчлөх шаардлагатай талбаруудыг бөглөөрэй. Хоосон үлдсэн талбарууд өөрчлөгдөхгүй хэвээр үлдэнэ.',
    'current_assets'    => 'Одоогоор ашиглагдаж буй активууд энэ хэрэглэгчийг шалгасан байна',
    'clone'             => 'Clone Хэрэглэгч',
    'contact_user'      => 'Холбоо барих нэр',
    'edit'              => 'Хэрэглэгчийг засварлах',
    'filetype_info'     => 'Зөвшөөрөгдсөн filetypes нь png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Түүх: нэр',
    'info'				=> 'Мэдээлэл',
    'restore_user'		=> 'Тэднийг сэргээхийн тулд энд дарна уу.',
    'last_login'        => 'Сүүлчийн Нэвтрэх',
    'ldap_config_text'  => 'LDAP тохиргооны тохиргоог Админ> Тохиргоо гэж олж болно. (Заавал биш) сонгосон байршлыг бүх импортлогчдын хувьд тохируулах болно.',
    'print_assigned'    => 'Бүх хуваарилагдсан хөрөнгийг хэвлэх',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Програм хангамж: нэр',
    'view_user'         => 'Хэрэглэгч: нэрийг харах',
    'usercsv'           => 'CSV файл',
    'two_factor_admin_optin_help' => 'Таны одоогийн админ тохиргоо нь хоёр хүчин зүйлийн баталгаажуулалтыг сонгохыг зөвшөөрдөг.',
    'two_factor_enrolled' => '2FA төхөөрөмжийг бүртгүүлсэн',
    'two_factor_active'   => '2FA идэвхтэй',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
    'department_manager' => 'Department Manager',
];
